Skip to content
KitploitKITPLOIT
OutilsExploitsBlog
Log in
Soumettre
OutilsExploitsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

··Flux·Contact·Confidentialité·© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
CVE2PoC — CVE2PoC est un outil qui aide les testeurs d'intrusion, les chasseurs de bugs et les chercheurs en sécurité à trouver rapidement des exploits publics ou des PoCs liés à un identifiant CVE. | Kitploit
Outils/GitHubGitHub/0liverflow/cve2poc
ReconnaissanceAnalyse des VulnérabilitésExploitationCollecte d'InformationsTests d'IntrusionRenseignement sur les MenacesApprentissage et ÉducationLabs et Pratique
GitHub0liverflow/cve2poc

CVE2PoC

CVE2PoC est un outil qui aide les testeurs d'intrusion, les chasseurs de bugs et les chercheurs en sécurité à trouver rapidement des exploits publics ou des PoCs liés à un identifiant CVE.

1452424il y a 16 joursVérifié par Kitploit

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Voir le dépôt
Partager

CVE2PoC

Python Version 1.1 License Maintained

CVE2PoC est un outil qui aide les testeurs d'intrusion, les chasseurs de bugs et les chercheurs en sécurité à trouver rapidement des exploits publics, des Preuves de Concept (PoC) et des avis liés à un ID CVE.

Table des matières

  • Fonctionnalités
  • Installation
  • Utilisation
    • Recherche d'exploits publics
    • Génération de rapports
    • Description d'une CVE
    • Environnements Docker vulnérables et laboratoires pratiques
    • Rapports Bug Bounty
    • Étapes de remédiation
    • Documentation des exploits
    • De CPE vers CVE
    • De CVE vers CPE
    • Filtres
  • Configuration post-installation
  • Linting et formatage
  • Crédits
  • Avertissement

Fonctionnalités

  • 🔍 Agrégation d'exploits publics : Recherche et centralise les exploits publics de GitHub, Nuclei, ExploitDB et Metasploit
  • 🐳 Environnements de test isolés : Environnements basés sur Docker pour tester les exploits en toute sécurité
  • 📊 Renseignements sur les CVE : Récupère CVSS, CWE, EPSS, CISA KEV, chaîne vectorielle
  • 📢 Avis de sécurité : Avis des éditeurs et références GHSA
  • 📝 Génération de rapports : Rapport technique détaillé
  • ✨ Facilité d'utilisation : Configuration simple et utilisation intuitive
  • 🎯 Laboratoires pratiques : Laboratoires HackTheBox et TryHackMe liés à un ID CVE
  • 🐞 Rapports Bug Bounty : Comptes rendus (write-ups) de Bug Bounty liés à un ID CVE
  • 🛠️ Étapes de remédiation : Étapes de remédiation pour corriger une vulnérabilité
  • ↔️ Correspondance CVE/CPE : Récupère les CVE liées à un CPE et vice-versa

Installation

CVE2PoC peut être installé à l'aide de pipx ou uv.

Pipx

pipx install git+https://github.com/0liverFlow/cve2poc

Uv

uv tool install git+https://github.com/0liverFlow/CVE2PoC
uvx git+https://github.com/0liverFlow/CVE2PoC

Utilisation

L'utilisation de CVE2PoC est simple. Vous pouvez l'utiliser en spécifiant simplement un ID CVE.

Consultez le menu d'aide et la section de démonstration ci-dessous pour mieux comprendre les fonctionnalités de l'outil.

usage: cve2poc.py [-h] [-x] [-d] [-f FILE] [-o OUTPUT] [-l LANGUAGE] [--limit LIMIT] [-t] [--labs CVE ID]
                  [--bugbounty-reports CVE ID] [--mitigations CVE ID] [--cve2cpe CVE ID] [--cpe2cve CPE] [-s FILE]
                  [--api-keys] [--no-banner]
                  [cve]

A simple yet powerful tool to quickly find PoCs related to a CVE ID

positional arguments:
  cve                               CVE ID

options:
  -h, --help                        show this help message and exit
  -x , --examine                    Examine an exploit's README file
  -d, --description                 Display a CVE ID description
  -f FILE, --file FILE              Specify a file containing a list of CVE IDs
  -o OUTPUT, --output OUTPUT        Output directory to store the reports
  -l LANGUAGE, --language LANGUAGE  Filter PoCs by programming language
  --limit LIMIT                     Number of PoCs to display
  -t , --threads                    Number of concurrent threads
  --labs CVE ID                     Search pre-built docker environments and Hands-on labs related to a CVE ID
  --bugbounty-reports CVE ID        Search Bug Bounty reports related to a CVE ID
  --mitigations CVE ID              Remediation steps to fix a vulnerability
  --cve2cpe CVE ID                  Retrieve CPEs related to a CVE ID
  --cpe2cve CPE                     Retrieve CVEs related to a CPE
  -s FILE, --save FILE              Output file to save CPE2CVE results
  --api-keys                        Configure your GitHub and NVD API keys (Not required)
  --no-banner                       Remove banner

Recherche d'exploits publics

Exécutez cette commande pour rechercher les exploits publics liés à un ID CVE :

cve2poc <CVE ID>

Recherche d'exploits publics liés à un ID CVE

Par défaut, l'outil renvoie les 10 meilleurs exploits, triés selon leurs étoiles et leurs forks.
De plus, il recherche les modules Metasploit, les modèles Nuclei et les exploits Exploit-DB liés à l'ID CVE spécifié.

Génération de rapports

Pour rechercher plusieurs CVE, spécifiez un fichier contenant une liste d'ID CVE (une CVE par ligne) à l'aide de l'option -f :

cve2poc -f <file>

Génération de rapports

CVE2PoC_report

Par défaut, CVE2PoC génère automatiquement des rapports JSON et HTML détaillés dans le répertoire courant.
Pour utiliser un répertoire de sortie différent, utilisez l'option -o.

Pour tester cette fonctionnalité, utilisez les fichiers d'exemple fournis.

Description d'une CVE

La commande ci-dessous renvoie la description d'un ID CVE, ainsi que des références supplémentaires pour mieux comprendre la vulnérabilité :

cve2poc --description <CVE ID>

Description d'une CVE

Environnements Docker vulnérables et laboratoires pratiques

CVE2PoC peut être utilisé pour trouver des environnements Docker prêts à l'emploi et des laboratoires pratiques afin de comprendre et de tester les exploits en toute sécurité avant de les utiliser dans des environnements réels, réduisant ainsi le risque de perturbations de la production.

cve2poc --labs <CVE ID>

Environnements Docker vulnérables et laboratoires pratiques

Rapports Bug Bounty

Les rapports de Bug Bounty peuvent être utiles pour mieux comprendre comment une CVE a été exploitée dans des scénarios réels. Ils peuvent également contenir des PoC qui peuvent vous aider à reproduire la vulnérabilité.

cve2poc --bugbounty-reports <CVE ID>

Recherche de rapports Bug Bounty

Étapes de remédiation

Pour identifier rapidement les étapes de remédiation d'une vulnérabilité, utilisez cette commande :

cve2poc --mitigations <CVE ID>

Étapes de remédiation

Documentation des exploits

CVE2PoC dispose d'une fonctionnalité similaire à searchsploit -x, qui vous permet de lire le fichier README d'un exploit directement depuis votre terminal. C'est pratique, surtout si vous avez besoin de comprendre rapidement le fonctionnement de l'exploit sans utiliser votre navigateur.

Pour examiner la documentation de l'exploit, utilisez cette commande :

cve2poc --examine <GitHub Clone URL>
Télécharger l’outil